#!/bin/bash
# generated by getlino
set -e  # exit on error
echo -n "Checking supervisor status..."
sudo supervisorctl status | awk '{if ( $2 != "RUNNING" ) { print "ERROR: " $1 " is not running"; exit 1}}'
echo "... OK"
